library coding_buddy;

import 'package:coding_buddy/logic/service/connectivity_service.dart';
import 'package:flutter/material.dart';
import 'package:get/instance_manager.dart';

import 'logic/service/api_service.dart';
import 'package:dio/dio.dart' as dio;

import 'logic/service/localization_service.dart';

export 'package:get/get.dart';
export 'package:coding_buddy/logic/service/api_service.dart';
export 'package:coding_buddy/logic/service/connectivity_service.dart';
export 'package:coding_buddy/logic/service/local_storage.dart';
export 'package:coding_buddy/logic/service/location_service.dart';
export 'package:coding_buddy/logic/service/platform_info.dart';
export 'package:coding_buddy/logic/service/localization_service.dart';
export 'package:coding_buddy/logic/controller/base_controller.dart';
export 'package:coding_buddy/logic/helper/regex_validation.dart';
export 'package:coding_buddy/logic/helper/compression_utils.dart';
export 'package:coding_buddy/logic/helper/debug_utils.dart';
export 'package:coding_buddy/logic/helper/intl_formats.dart';
export 'package:coding_buddy/logic/helper/signature_generator.dart';
export 'package:coding_buddy/ui/helper/screen_utils.dart';
export 'package:coding_buddy/ui/helper/text_style_utils.dart';
export 'package:intl/intl.dart';
export 'package:device_info/device_info.dart';
export 'package:flutter_image_compress/flutter_image_compress.dart';
export 'package:provider/provider.dart';
export 'package:shared_preferences/shared_preferences.dart';
export 'package:google_fonts/google_fonts.dart';
export 'package:geocoding/geocoding.dart';
export 'package:permission_handler/permission_handler.dart';

class CodingBuddy {
  static Color lightTextColor = Color(0xff25282b);
  static Color darkTextColor = Colors.white;

  static ThemeData lightTheme = ThemeData.light();
  static ThemeData darkTheme = ThemeData.dark();

  static ThemeData theme = lightTheme;

  static bool isPrototype = false;

  static String packageName = 'coding_buddy';

  static String baseUrl = "https://yustanj.portfoliobox.net";

  static CBApiService apiService = CBApiService(baseUrl);

  static CBLocalizationService localizationService;

  static Function(dio.Response<dynamic>) defaultErrorHandler = (response) {};

  static init() {
    CBConnectivityService.init();
  }

  static S useController<S>(
      {S dependency,
      String tag,
      bool permanent = true,
      InstanceBuilderCallback<S> builder}) {
    bool isRegistered = Get.isRegistered<S>(tag: tag);
    if (isRegistered) {
      return Get.find<S>(tag: tag);
    } else {
      return Get.put(dependency,
          tag: tag, permanent: permanent, builder: builder);
    }
  }
}

//class for cross module page
class CrossModule {}

class CrossModuleWidget {}

class CrossModuleController {}

class CrossModuleClass {}

extension crossModule on CrossModule {
  static CrossModuleWidget _widgets;
  CrossModuleWidget get widgets {
    return _widgets;
  }

  set widgets(CrossModuleWidget value) => _widgets = value;

  static CrossModuleController _controllers;
  CrossModuleController get controllers {
    return _controllers;
  }

  set controllers(CrossModuleController value) => _controllers = value;

  static CrossModuleClass _classes;
  CrossModuleClass get classes {
    return _classes;
  }

  set classes(CrossModuleClass value) => _classes = value;
}
