import 'package:encrypt/encrypt.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

class CBSignature {
  static Future<String> fromPath(String plainText,
      {String publicKeyPath, @required String privateKeyPath}) async {
    final publicKeyString = await rootBundle.loadString(publicKeyPath);
    final privateKeyString = await rootBundle.loadString(privateKeyPath);
    return fromString(plainText,
        publicKeyString: publicKeyString, privateKeyString: privateKeyString);
  }

  static Future<String> fromString(String plainText,
      {String publicKeyString, @required String privateKeyString}) async {
    final publicKey = publicKeyString == null
        ? null
        : RSAKeyParser().parse(publicKeyString);
    final privateKey = RSAKeyParser().parse(privateKeyString);
    final signer = Signer(RSASigner(RSASignDigest.SHA256,
        privateKey: privateKey, publicKey: publicKey));
    final certificate = signer.sign(plainText);
    return certificate.base64;
  }
}
