import 'package:coding_buddy/coding_buddy.dart' as Core;
import 'package:dio/dio.dart';

enum MethodRequest { POST, GET, PUT, DELETE }

class CBApiService {
  Dio _dio = Dio();

  CBApiService(String baseUrl) {
    _dio.options.baseUrl = baseUrl;
    _dio.options.connectTimeout = 90000; //90s
    _dio.options.receiveTimeout = 10000;
    _dio.options.headers = {'Accept': 'application/json'};
  }

  Future<Response> call(String url,
      {MethodRequest method = MethodRequest.POST,
      Map<String, dynamic> request,
      Map<String, String> header,
      String token,
      bool useFormData = false}) async {
    if (await Core.CBConnectivityService.connectionStatus.stream.last ==
        Core.CBConnectivityStatus.Offline) {
      Response response = Response(
        data: {
          //TODO change message to multi langauge
          "message": "You are offline",
          "status": "error",
        },
        statusCode: 00,
        requestOptions: null,
      );
      return response;
    }
    if (header != null) {
      _dio.options.headers = header;
    }
    if (token != null) {
      if (header != null) {
        header.addAll({'Authorization': 'Bearer $token'});
        _dio.options.headers = header;
      } else {
        _dio.options.headers = {
          'Accept': 'application/json',
          'Authorization': 'Bearer $token'
        };
      }
      if (method == MethodRequest.PUT) {
        _dio.options.headers = {
          'Accept': 'application/json',
          'Content-Type': 'application/x-www-form-urlencoded',
          'Authorization': 'Bearer $token',
        };
      }
    }

    Core.printDebug('URL : ${_dio.options.baseUrl}$url');
    Core.printDebug('Method : $method');
    Core.printDebug("Header : ${_dio.options.headers}");
    Core.printDebug("Request : $request");

    var selectedMethod;
    try {
      Response response;
      switch (method) {
        case MethodRequest.GET:
          selectedMethod = method;
          response = await _dio.get(url, queryParameters: request);
          break;
        case MethodRequest.PUT:
          selectedMethod = method;
          response = await _dio.put(
            url,
            data: useFormData ? FormData.fromMap(request) : request,
          );
          break;
        case MethodRequest.DELETE:
          selectedMethod = method;
          response = await _dio.delete(
            url,
            data: useFormData ? FormData.fromMap(request) : request,
          );
          break;
        default:
          selectedMethod = MethodRequest.POST;
          response = await _dio.post(
            url,
            data: useFormData ? FormData.fromMap(request) : request,
          );
      }
      Core.printDebug(
          'Success $selectedMethod $url: \nResponse : ${response.data}');
      return response;
    } on DioError catch (e) {
      Core.printDebug(
          'Error $selectedMethod $url: $e\nData: ${e.response?.data}');
      if (e.response?.data is Map) {
        (e.response.data as Map).addAll(<String, dynamic>{
          "status": "error",
        });
        Core.CodingBuddy.defaultErrorHandler(e.response);
        return e.response;
      } else {
        Response response = Response(
          data: {
            //TODO change message to multi langauge
            "message": "Terjadi kesalahan, coba lagi beberapa saat",
            "status": "error",
          },
          requestOptions: e.requestOptions,
          statusCode: e.response.statusCode,
        );
        Core.CodingBuddy.defaultErrorHandler(response);
        return response;
      }
    }
  }
}
