import 'package:coding_buddy/logic/helper/debug_utils.dart';
import 'package:encrypt/encrypt.dart';
import 'package:shared_preferences/shared_preferences.dart';

class CBLocalStorage {
  static SharedPreferences prefs;

  static final _key = Key.fromUtf8('yustan.julmakap.');
  static final _iv = IV.fromLength(16);
  static final _encrypter = Encrypter(AES(_key));

  /// Get dynamic value from all type preferences
  static dynamic getFromDisk(String key, {bool decrypt = false}) {
    assert(prefs != null);
    var value = prefs.get(key);
    if (decrypt && value!=null) value = _encrypter.decrypt64(value, iv: _iv);
    printDebug(
        '(TRACE) LocalStorageService:_getFromDisk. key: $key value: $value instansce of: ${value.runtimeType}');
    if (value is List) return value.cast<String>();
    return value;
  }

  /// Save data function that handles all types
  static void saveToDisk<T>(String key, T content, {bool encrypt = false}) {
    assert(prefs != null);
    printDebug(
        '(TRACE) LocalStorageService:_saveToDisk. key: $key value: $content');
    if (content == null) {
      prefs.remove(key);
    }
    if (content is String) {
      if (encrypt) {
        var contentEncrypted = _encrypter.encrypt(content, iv: _iv);
        prefs.setString(key, contentEncrypted.base64);
      } else {
        prefs.setString(key, content);
      }
    }
    if (content is bool) {
      prefs.setBool(key, content);
    }
    if (content is int) {
      prefs.setInt(key, content);
    }
    if (content is double) {
      prefs.setDouble(key, content);
    }
    if (content is List<String>) {
      prefs.setStringList(key, content);
    }
  }
}
