import 'dart:ui';

import 'package:coding_buddy/coding_buddy.dart';
import 'package:flutter/material.dart';

class CBLocalizationService extends Translations {
  CBLocalizationService({
    Locale defaultlocale = const Locale('en', 'US'),
    Locale fallbacklocale = const Locale('en', 'US'),
    @required List<Language> supportedlang,
    Function(String) onlocalechanged,
  }) {
    locale = defaultlocale;
    fallbackLocale = fallbacklocale;
    supportedlang.forEach(
      (element) {
        langs.add(element.language);
        locales.add(element.locale);
        _keys.addAll({
          "${element.locale.languageCode}_${element.locale.countryCode}":
              element.key
        });
      },
    );
    if (onlocalechanged != null) onLocaleChanged = onlocalechanged;
  }

  Function(String) onLocaleChanged = (language) {
    printDebug(
        "If you see this message it means you haven't notified other apps or modules when logging in");
  };

  // Default locale
  Locale locale = Locale('en', 'US');

  // fallbackLocale saves the day when the locale gets in trouble
  Locale fallbackLocale = Locale('en', 'US');

  // Supported languages
  // Needs to be same order with locales
  List<String> langs = [];

  // Supported locales
  // Needs to be same order with langs
  List<Locale> locales = [];

  // Keys and their translations
  // Translations are separated maps in `lang` file
  Map<String, Map<String, String>> _keys = {};
  @override
  Map<String, Map<String, String>> get keys => _keys;

  // Gets locale from language, and updates the locale
  void changeLocale(String lang) {
    final locale = _getLocaleFromLanguage(lang);
    Get.updateLocale(locale);
    onLocaleChanged(lang);
  }

  // Finds language in `langs` list and returns it as Locale
  Locale _getLocaleFromLanguage(String lang) {
    for (int i = 0; i < langs.length; i++) {
      if (lang == langs[i]) return locales[i];
    }
    return Get.locale;
  }
}

class Language {
  final String language;
  final Locale locale;
  final Map<String, String> key;

  Language(
      {@required this.language, @required this.locale, @required this.key});
}
