import 'package:coding_buddy/logic/helper/debug_utils.dart';
import 'package:geocoding/geocoding.dart';
import 'package:location/location.dart' as loc;

class CBLocationService {
  static loc.Location _location = new loc.Location();

  static Future<CBLocationResult> getLocation({String localeIdentifier}) async {
    bool _serviceEnabled;
    loc.PermissionStatus _permissionGranted;
    loc.LocationData _locationData;

    _serviceEnabled = await _location.serviceEnabled();
    if (!_serviceEnabled) {
      _serviceEnabled = await _location.requestService();
    }

    printDebug('Service : $_serviceEnabled');

    _permissionGranted = await _location.hasPermission();
    if (_permissionGranted == loc.PermissionStatus.denied) {
      _permissionGranted = await _location.requestPermission();
    }

    printDebug('Permission Granted : $_permissionGranted');

    _locationData = await _location.getLocation();
    printDebug(
        'Location : ${_locationData.latitude}, ${_locationData.longitude}');

    var _placemarks = await placemarkFromCoordinates(
        _locationData.latitude, _locationData.longitude,
        localeIdentifier: localeIdentifier);
    return CBLocationResult(location: _locationData, placemarks: _placemarks);
  }
}

class CBLocationResult {
  final loc.LocationData location;
  final List<Placemark> placemarks;

  CBLocationResult({this.location, this.placemarks});
}
